@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -18,8 +18,8 @@
 #include <iostream>
 #include <string>
 
-#include "modsecurity/rules_properties.h"
-#include "modsecurity/rules.h"
+#include "modsecurity/rules_set_properties.h"
+#include "modsecurity/rules_set.h"
 #include "modsecurity/transaction.h"
 
 namespace modsecurity {
@@ -31,11 +31,11 @@ bool RuleEngine::init(std::string *error) {
     std::string what(m_parser_payload, 11, m_parser_payload.size() - 11);
 
     if (what == "on") {
-        m_ruleEngine = RulesProperties::EnabledRuleEngine;
+        m_ruleEngine = RulesSetProperties::EnabledRuleEngine;
     } else if (what == "off") {
-        m_ruleEngine = RulesProperties::DisabledRuleEngine;
+        m_ruleEngine = RulesSetProperties::DisabledRuleEngine;
     } else if (what == "detectiononly") {
-        m_ruleEngine = RulesProperties::DetectionOnlyRuleEngine;
+        m_ruleEngine = RulesSetProperties::DetectionOnlyRuleEngine;
     } else {
         error->assign("Internal error. Expected: On, Off or DetectionOnly; " \
             "got: " + m_parser_payload);
@@ -45,10 +45,10 @@ bool RuleEngine::init(std::string *error) {
     return true;
 }
 
-bool RuleEngine::evaluate(Rule *rule, Transaction *transaction) {
+bool RuleEngine::evaluate(RuleWithActions *rule, Transaction *transaction) {
     std::stringstream a;
     a << "Setting SecRuleEngine to ";
-    a << modsecurity::RulesProperties::ruleEngineStateString(m_ruleEngine);
+    a << modsecurity::RulesSetProperties::ruleEngineStateString(m_ruleEngine);
     a << " as requested by a ctl:ruleEngine action";
 
     ms_dbg_a(transaction, 8, a.str());
